# 🔝 `yt-mpv`

Watch a YouTube video without ads, while archiving to archive.org.

Currently Linux only.

## usage

```bash
uvx yt-mpv install
```

Follow instructions to configure internet archive credentials, then drag the
link to your bookmarks bar.

## License

WTFPL with warranty clause:

1. don't blame me

## Notes

This is what you get when you put 4 minutes of adverts after every 6 minutes
of content.
